pub struct Channel {
pub channel_type: Option<String>,
pub name: Option<String>,
}Expand description
Each Channel is owned by a Platform and owns a collection of versions. Possible Channels are listed in the Channel enum below. Not all Channels are available for every Platform (e.g. CANARY does not exist for LINUX).
This type is not used in any activity, and only used as part of another schema.
Fields
channel_type: Option<String>Type of channel.
name: Option<String>Channel name. Format is “{product}/platforms/{platform}/channels/{channel}”