Release

Struct Release 

pub struct Release {
    pub fraction: Option<f64>,
    pub fraction_group: Option<i64>,
    pub name: Option<String>,
    pub pinnable: Option<bool>,
    pub rollout_data: Option<Vec<RolloutData>>,
    pub serving: Option<Interval>,
    pub version: Option<String>,
}
A Release is owned by a Version. A Release contains information about the release(s) of its parent version. This includes when the release began and ended, as well as what percentage it was released at. If the version is released again, or if the serving percentage changes, it will create another release under the version.

This type is not used in any activity, and only used as part of another schema.

Fields

fraction: Option<f64>

Rollout fraction. This fraction indicates the fraction of people that should receive this version in this release. If the fraction is not specified in ReleaseManager, the API will assume fraction is 1.

fraction_group: Option<i64>

Rollout fraction group. Only fractions with the same fraction_group are statistically comparable: there may be non-fractional differences between different fraction groups.

name: Option<String>

Release name. Format is “{product}/platforms/{platform}/channels/{channel}/versions/{version}/releases/{release}”

pinnable: Option<bool>

Whether or not the release was available for version pinning.

rollout_data: Option<Vec<RolloutData>>

Rollout-related metadata. Some releases are part of one or more A/B rollouts. This field contains the names and data describing this release’s role in any rollouts.

serving: Option<Interval>

Timestamp interval of when the release was live. If end_time is unspecified, the release is currently live.

version: Option<String>

String containing just the version number. e.g. “84.0.4147.38”