pub struct RolloutData {
pub rollout_name: Option<String>,
pub tag: Option<Vec<String>>,
}Expand description
Rollout-related metadata for a release.
This type is not used in any activity, and only used as part of another schema.
Fields
rollout_name: Option<String>The name of the rollout.
tag: Option<Vec<String>>Tags associated with a release’s role in a rollout. Most rollouts will have at least one release with a “rollout” tag and another release with a “control” tag. Some rollouts may have additional named arms.